﻿Imports Microsoft.VisualBasic
Imports System
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Windows.Forms
Imports Syncfusion.Windows.Forms
Imports Syncfusion.Windows.Forms.Renderers

Namespace ScrollersFrame_CustomRender
	Partial Public Class Form1
		Inherits Form
		Private colorTable As New MetroColorTable()
		Public Sub New()
			InitializeComponent()
			Me.scrollersFrame1.CustomRender = New BasicRenderer(True)

			colorTable.ArrowChecked = Color.Red
			colorTable.ArrowNormal = Color.Blue
			colorTable.ArrowInActive = Color.Yellow
			colorTable.ArrowNormalBackGround = Color.Orange
			colorTable.ArrowPushed = Color.White
			colorTable.ArrowPushedBackGround = Color.Green
			colorTable.ScrollerBackground = Color.LightSkyBlue
			colorTable.ThumbChecked = Color.Blue
			colorTable.ThumbInActive = Color.Orange
			colorTable.ThumbNormal = Color.Olive
			colorTable.ThumbPushed = Color.HotPink
			colorTable.ThumbPushedBorder = Color.Indigo

			Me.scrollersFrame2.ScrollMetroColorTable = colorTable
			Me.scrollersFrame2.VisualStyle = ScrollBarCustomDrawStyles.Metro
		End Sub
	End Class

	Public Class BasicRenderer
		Implements IRenderer
		#Region "class members"
		''' <summary></summary>
		Protected m_parent As ScrollBarCustomDraw
		''' <summary>
		''' Indicates whether scroll is vertical or horizontal
		''' </summary>
		Protected m_isVerticalScroll As Boolean = False
		#End Region

		#Region "class properties"
		''' <summary></summary>
		Protected ReadOnly Property Parent() As ScrollBarCustomDraw
			Get
				Return m_parent
			End Get
		End Property
		#End Region

		#Region "class initialize\finalize methods"
		''' <summary></summary>
		''' <param name="isVerticalScrollBar"/>
		Public Sub New(ByVal isVerticalScrollBar As Boolean)
			m_isVerticalScroll = isVerticalScrollBar
		End Sub

		''' <summary></summary>
		''' <param name="parent"/>
		Public Sub New(ByVal parent As ScrollBarCustomDraw)
			m_parent = parent

			If TypeOf parent Is HScrollBarCustomDraw Then
				IsVerticalScrollBar = False
			ElseIf TypeOf parent Is VScrollBarCustomDraw Then
				IsVerticalScrollBar = True
			End If
		End Sub
		#End Region

		#Region "class implements IRenderer"
		''' <summary>
		''' Indicates whether scrollBar is vertical or horizontal.
		''' </summary>
		Public Overridable Property IsVerticalScrollBar() As Boolean
			Get
				Return m_isVerticalScroll
			End Get
			Set(ByVal value As Boolean)
				If m_isVerticalScroll <> value Then
					m_isVerticalScroll = value
				End If
			End Set
		End Property

		''' <summary></summary>
		''' <param name="g"></param>
		''' <param name="bounds"></param>
		''' <param name="state"/>
        Public Overridable Sub DrawBackground(ByVal g As Graphics, ByVal bounds As Rectangle, ByVal state As ButtonState) Implements IRenderer.DrawBackground
            If Nothing Is g Then
                Throw New ArgumentNullException("g")
            End If

            If bounds.Width > 0 AndAlso bounds.Height > 0 Then
                Dim backColor As Color = SystemColors.ControlLight

                Using bgBrush As Brush = New SolidBrush(backColor)
                    g.FillRectangle(bgBrush, bounds)
                End Using

                If state = ButtonState.Pushed Then
                    Dim clrHighlight As Color = SystemColors.Highlight
                    Dim clrSelect As Color = Color.FromArgb(200, clrHighlight)

                    Using bgBrush As Brush = New SolidBrush(clrSelect)
                        g.FillRectangle(bgBrush, bounds)
                    End Using
                End If
            End If
        End Sub

		''' <summary></summary>
		''' <param name="g"></param>
		''' <param name="bounds"></param>
		''' <param name="type"></param>
        ''' <param name="state"></param>
        Public Overridable Sub DrawArrowButton(ByVal g As Graphics, ByVal bounds As Rectangle, ByVal type As ScrollButton, ByVal state As ButtonState) Implements IRenderer.DrawArrowButton
            If Nothing Is g Then
                Throw New ArgumentNullException("g")
            End If

            If bounds.Height > 0 AndAlso bounds.Width > 0 Then
                ControlPaint.DrawScrollButton(g, bounds, type, state)
            End If
        End Sub

		''' <summary></summary>
		''' <param name="g"></param>
		''' <param name="bounds"></param>
		''' <param name="state"></param>
        Public Overridable Sub DrawThumb(ByVal g As Graphics, ByVal bounds As Rectangle, ByVal state As ButtonState) Implements IRenderer.DrawThumb
            If Nothing Is g Then
                Throw New ArgumentNullException("g")
            End If

            If bounds.Width > 0 AndAlso bounds.Height > 0 Then
                If state = ButtonState.Inactive Then
                    DrawBackground(g, bounds, state)
                Else
                    ControlPaint.DrawButton(g, bounds, state)
                End If
            End If
        End Sub
		#End Region
	End Class
End Namespace
